Developer Information
=====================

Welcome to the "Stylist" code stye checking tool developer documentation.

If you want to use the tool you may find the `User Guide`_ more to
your taste.

.. _User Guide: ../user-manual

.. toctree::
   :maxdepth: 2

   overview
   api
   environment
   rules
   todo

A lot of our process is dictated by the GitHub platform used to host the
project. For details about that, such as how change requests are handled,
see the `project wiki`_.

.. _project wiki: https://github.com/MetOffice/stylist/wiki

Indices and tables
------------------

* :ref:`modindex`
* :ref:`genindex`
* :ref:`search`
